@@ -44,6 +44,10 @@ const (
 	ArgAppLogType = "type"
 	// ArgAppDeployment is the deployment ID.
 	ArgAppDeployment = "deployment"
+	// ArgAppJobName is the job name.
+	ArgAppJobName = "job-name"
+	// ArgAppJobInvocation is the job invocation ID.
+	ArgAppJobInvocation = "job-invocation"
 	// ArgAppInstanceName is the instance name of currently running instances (optional).
 	ArgAppInstanceName = "instance-name"
 	// ArgAppDevConfig is the path to the app dev link config.
@@ -153,6 +157,10 @@ const (
 	ArgEnableAmdGpuDevicePlugin = "enable-amd-gpu-device-plugin"
 	// ArgEnableAmdGpuDeviceMetricsExporterPlugin enables automatic amd gpu device metrics exporter plugin installation.
 	ArgEnableAmdGpuDeviceMetricsExporterPlugin = "enable-amd-gpu-device-metrics-exporter-plugin"
+	// ArgEnableNvidiaGpuDevicePlugin enables automatic NVIDIA gpu device plugin installation.
+	ArgEnableNvidiaGpuDevicePlugin = "enable-nvidia-gpu-device-plugin"
+	// ArgEnableRDMASharedDevicePlugin enables automatic NVIDIA gpu device plugin installation.
+	ArgEnableRDMASharedDevicePlugin = "enable-rdma-shared-device-plugin"
 	// ArgSurgeUpgrade is a cluster's surge-upgrade argument.
 	ArgSurgeUpgrade = "surge-upgrade"
 	// ArgCommandUpsert is an upsert for a resource to be created or updated argument.
